(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('feature-toggle-service'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', 'feature-toggle-service', '@angular/common'], factory) :
	(factory((global['ngx-feature-toggle'] = {}),global.ng.core,global.FeatureToggleService,global.ng.common));
}(this, (function (exports,core,featureToggleService,common) { 'use strict';

var FeatureToggleProviderComponent = /** @class */ (function () {
    function FeatureToggleProviderComponent() {
        this.features = {};
        this.currentConfig = {};
    }
    FeatureToggleProviderComponent.prototype.ngOnInit = function () {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `featureToggleService` should not be null or empty');
        }
        this.setFeatureToggles();
    };
    FeatureToggleProviderComponent.prototype.ngDoCheck = function () {
        var shouldUpdateFeatureToggles = this.currentConfig !== this.features;
        if (shouldUpdateFeatureToggles) {
            this.setFeatureToggles();
        }
    };
    FeatureToggleProviderComponent.prototype.setFeatureToggles = function () {
        this.currentConfig = this.features;
        featureToggleService.setConfigurationObject(this.features);
    };
    return FeatureToggleProviderComponent;
}());
FeatureToggleProviderComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'feature-toggle-provider',
                template: "<ng-content></ng-content>"
            },] },
];
FeatureToggleProviderComponent.ctorParameters = function () { return []; };
FeatureToggleProviderComponent.propDecorators = {
    "features": [{ type: core.Input },],
};
var FeatureToggleComponent = /** @class */ (function () {
    function FeatureToggleComponent(_el, _zone) {
        this._el = _el;
        this._zone = _zone;
        this.isEnabled = false;
        this.featureIsEnabled = false;
    }
    FeatureToggleComponent.prototype.ngOnInit = function () {
        if (!this.featureName) {
            throw new Error('Attribute `featureName` should not be null or empty');
        }
        this.checkIfContentShouldBeRendered();
    };
    FeatureToggleComponent.prototype.ngDoCheck = function () {
        var _this = this;
        this._zone.runOutsideAngular(function () {
            _this.checkIfContentShouldBeRendered();
        });
    };
    FeatureToggleComponent.prototype.checkIfContentShouldBeRendered = function () {
        var showWhenDisabled = this._el.nativeElement.getAttribute('showWhenDisabled') !== null;
        var toggleState = featureToggleService.isOn(this.featureName);
        this.featureIsEnabled = toggleState === !showWhenDisabled;
        if (this.isEnabled !== this.featureIsEnabled) {
            this.isEnabled = this.featureIsEnabled;
        }
    };
    return FeatureToggleComponent;
}());
FeatureToggleComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'feature-toggle',
                template: '<ng-content *ngIf="isEnabled"></ng-content>'
            },] },
];
FeatureToggleComponent.ctorParameters = function () { return [
    { type: core.ElementRef, },
    { type: core.NgZone, },
]; };
FeatureToggleComponent.propDecorators = {
    "featureName": [{ type: core.Input },],
};
var ANGULAR_FEATURE_TOGGLE_DIRECTIVES = [
    FeatureToggleProviderComponent,
    FeatureToggleComponent
];
var ANGULAR_FEATURE_TOGGLE_PROVIDERS = [];
var FeatureToggleModule = /** @class */ (function () {
    function FeatureToggleModule() {
    }
    return FeatureToggleModule;
}());
FeatureToggleModule.decorators = [
    { type: core.NgModule, args: [{
                declarations: ANGULAR_FEATURE_TOGGLE_DIRECTIVES,
                exports: ANGULAR_FEATURE_TOGGLE_DIRECTIVES,
                providers: ANGULAR_FEATURE_TOGGLE_PROVIDERS,
                imports: [common.CommonModule]
            },] },
];
FeatureToggleModule.ctorParameters = function () { return []; };

exports.FeatureToggleModule = FeatureToggleModule;
exports.ɵa = FeatureToggleProviderComponent;
exports.ɵb = FeatureToggleComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-feature-toggle.umd.js.map
