import { Component, Input, ElementRef, NgZone, NgModule } from '@angular/core';
import { setConfigurationObject, isOn } from 'feature-toggle-service';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FeatureToggleProviderComponent {
    constructor() {
        this.features = {};
        this.currentConfig = {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `featureToggleService` should not be null or empty');
        }
        this.setFeatureToggles();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        const /** @type {?} */ shouldUpdateFeatureToggles = this.currentConfig !== this.features;
        if (shouldUpdateFeatureToggles) {
            this.setFeatureToggles();
        }
    }
    /**
     * @return {?}
     */
    setFeatureToggles() {
        this.currentConfig = this.features;
        setConfigurationObject(this.features);
    }
}
FeatureToggleProviderComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle-provider',
                template: `<ng-content></ng-content>`
            },] },
];
/** @nocollapse */
FeatureToggleProviderComponent.ctorParameters = () => [];
FeatureToggleProviderComponent.propDecorators = {
    "features": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FeatureToggleComponent {
    /**
     * @param {?} _el
     * @param {?} _zone
     */
    constructor(_el, _zone) {
        this._el = _el;
        this._zone = _zone;
        this.isEnabled = false;
        this.featureIsEnabled = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.featureName) {
            throw new Error('Attribute `featureName` should not be null or empty');
        }
        this.checkIfContentShouldBeRendered();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        this._zone.runOutsideAngular(() => {
            this.checkIfContentShouldBeRendered();
        });
    }
    /**
     * @return {?}
     */
    checkIfContentShouldBeRendered() {
        const /** @type {?} */ showWhenDisabled = this._el.nativeElement.getAttribute('showWhenDisabled') !== null;
        const /** @type {?} */ toggleState = isOn(this.featureName);
        this.featureIsEnabled = toggleState === !showWhenDisabled;
        if (this.isEnabled !== this.featureIsEnabled) {
            this.isEnabled = this.featureIsEnabled;
        }
    }
}
FeatureToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle',
                template: '<ng-content *ngIf="isEnabled"></ng-content>'
            },] },
];
/** @nocollapse */
FeatureToggleComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: NgZone, },
];
FeatureToggleComponent.propDecorators = {
    "featureName": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const ANGULAR_FEATURE_TOGGLE_DIRECTIVES = [
    FeatureToggleProviderComponent,
    FeatureToggleComponent
];
const ANGULAR_FEATURE_TOGGLE_PROVIDERS = [];
class FeatureToggleModule {
}
FeatureToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: ANGULAR_FEATURE_TOGGLE_DIRECTIVES,
                exports: ANGULAR_FEATURE_TOGGLE_DIRECTIVES,
                providers: ANGULAR_FEATURE_TOGGLE_PROVIDERS,
                imports: [CommonModule]
            },] },
];
/** @nocollapse */
FeatureToggleModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { FeatureToggleModule, FeatureToggleProviderComponent as ɵa, FeatureToggleComponent as ɵb };
//# sourceMappingURL=ngx-feature-toggle.js.map
