import { Component, Input, ElementRef, NgZone, NgModule } from '@angular/core';
import { setConfigurationObject, isOn } from 'feature-toggle-service';
import { CommonModule } from '@angular/common';

var FeatureToggleProviderComponent = /** @class */ (function () {
    function FeatureToggleProviderComponent() {
        this.features = {};
        this.currentConfig = {};
    }
    FeatureToggleProviderComponent.prototype.ngOnInit = function () {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `featureToggleService` should not be null or empty');
        }
        this.setFeatureToggles();
    };
    FeatureToggleProviderComponent.prototype.ngDoCheck = function () {
        var shouldUpdateFeatureToggles = this.currentConfig !== this.features;
        if (shouldUpdateFeatureToggles) {
            this.setFeatureToggles();
        }
    };
    FeatureToggleProviderComponent.prototype.setFeatureToggles = function () {
        this.currentConfig = this.features;
        setConfigurationObject(this.features);
    };
    return FeatureToggleProviderComponent;
}());
FeatureToggleProviderComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle-provider',
                template: "<ng-content></ng-content>"
            },] },
];
FeatureToggleProviderComponent.ctorParameters = function () { return []; };
FeatureToggleProviderComponent.propDecorators = {
    "features": [{ type: Input },],
};
var FeatureToggleComponent = /** @class */ (function () {
    function FeatureToggleComponent(_el, _zone) {
        this._el = _el;
        this._zone = _zone;
        this.isEnabled = false;
        this.featureIsEnabled = false;
    }
    FeatureToggleComponent.prototype.ngOnInit = function () {
        if (!this.featureName) {
            throw new Error('Attribute `featureName` should not be null or empty');
        }
        this.checkIfContentShouldBeRendered();
    };
    FeatureToggleComponent.prototype.ngDoCheck = function () {
        var _this = this;
        this._zone.runOutsideAngular(function () {
            _this.checkIfContentShouldBeRendered();
        });
    };
    FeatureToggleComponent.prototype.checkIfContentShouldBeRendered = function () {
        var showWhenDisabled = this._el.nativeElement.getAttribute('showWhenDisabled') !== null;
        var toggleState = isOn(this.featureName);
        this.featureIsEnabled = toggleState === !showWhenDisabled;
        if (this.isEnabled !== this.featureIsEnabled) {
            this.isEnabled = this.featureIsEnabled;
        }
    };
    return FeatureToggleComponent;
}());
FeatureToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle',
                template: '<ng-content *ngIf="isEnabled"></ng-content>'
            },] },
];
FeatureToggleComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: NgZone, },
]; };
FeatureToggleComponent.propDecorators = {
    "featureName": [{ type: Input },],
};
var ANGULAR_FEATURE_TOGGLE_DIRECTIVES = [
    FeatureToggleProviderComponent,
    FeatureToggleComponent
];
var ANGULAR_FEATURE_TOGGLE_PROVIDERS = [];
var FeatureToggleModule = /** @class */ (function () {
    function FeatureToggleModule() {
    }
    return FeatureToggleModule;
}());
FeatureToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: ANGULAR_FEATURE_TOGGLE_DIRECTIVES,
                exports: ANGULAR_FEATURE_TOGGLE_DIRECTIVES,
                providers: ANGULAR_FEATURE_TOGGLE_PROVIDERS,
                imports: [CommonModule]
            },] },
];
FeatureToggleModule.ctorParameters = function () { return []; };

export { FeatureToggleModule, FeatureToggleProviderComponent as ɵa, FeatureToggleComponent as ɵb };
//# sourceMappingURL=ngx-feature-toggle.js.map
